#
# spec file for package python-blurb
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%bcond_without libalternatives
%{?sle15_python_module_pythons}
Name:           python-blurb
Version:        2.0.0
Release:        2.1
Summary:        Command-line tool to manage CPython Misc/NEWS.d entries
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/python/core-workflow/tree/master/blurb
Source:         https://files.pythonhosted.org/packages/source/b/blurb/blurb-%{version}.tar.gz
BuildRequires:  %{python_module hatch_vcs}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyfakefs}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module time-machine}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
BuildArch:      noarch
%python_subpackages

%description
Command-line tool to manage CPython Misc/NEWS.d entries.

%prep
%autosetup -p1 -n blurb-%{version}

sed -i '1{\,^#!%{_bindir}/env python,d}' src/blurb/blurb.py
chmod -x src/blurb/blurb.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/blurb
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%pre
%python_libalternatives_reset_alternative blurb

%files %{python_files}
%doc README.md
%license LICENSE.txt
%python_alternative %{_bindir}/blurb
%{python_sitelib}/blurb
%{python_sitelib}/blurb-%{version}*-info

%changelog
* Tue Jun 17 2025 Markéta Machová <mmachova@suse.com>
- Convert to libalternatives
* Mon Jan 27 2025 Nico Krapp <nico.krapp@suse.com>
- Update to 2.0.0
  * Move blurb test subcommand into test suite by @hugovk in #37
  * Add support for Python 3.14 by @ezio-melotti in #40
  * Validate gh-issue is int before checking range, and that gh-issue or bpo exists by @hugovk in #35
  * Replace safe_mkdir(path) with os.makedirs(path, exist_ok=True) by @hugovk in #38
  * Test version handling functions by @hugovk in #36
  * Test textwrap_body, current_date and sortable_datetime by @hugovk in #42
  * CI: Lint and test via uv by @hugovk in #32
* Wed Dec 11 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.3.0
  * Add support for Python 3.13
  * Drop support for Python 3.8
  * Generate digital attestations for PyPI (PEP 740)
  * Allow running blurb test from blurb-* directories
  * Add `version` subcommand
  * Generate `__version__` at build to avoid slow `importlib.metadata` import
- from version 1.2.1
  * Fix `python3 -m blurb`.
  * Undocument removed `blurb split`.
- from version 1.2.0
  * Replace spaces with underscores in news directory.
  * Drop support for Python 3.7.
  * Remove `blurb split` command.
  * Replace `gh-issue-NNNN:` with `gh-NNNN:` in the output.
  * Accept GitHub issues numbered only 32426 or above.
  * Improve error checking when parsing a Blurb.
  * Loosen README check for CPython forks.
  * Move code from `python/core-workflow` to own `python/blurb` repo.
  * Deploy to PyPI via Trusted Publishers.
- Adjust file paths for sed invocation in %%setup section
- Replace manual testsuite invocation with just %%pytest
- Update BuildRequires from pyproject.toml
- Update file patterns in %%files section
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- build for python3 module on SLE15
* Fri May 20 2022 Matej Cepl <mcepl@suse.com>
- Update to 1.1.0:
  - Support GitHub Issues in addition to b.p.o
    (bugs.python.org). If "gh-issue" is in the metadata, then the
    filename will contain "gh-issue-<number>" instead of "bpo-".
* Tue May 18 2021 pgajdos@suse.com
- version update to 1.0.8
  * no upstream changelog (see github log)
- test package via %%pytest macro
* Thu Apr 16 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 1.0.7
